==> chromium-browser_13.0.782.220~r99552.orig.tar.bz2: chromium-13.0.782.220~r99552/src/webkit/plugins/ppapi/ppapi_interface_factory.cc <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "webkit/plugins/ppapi/ppapi_interface_factory.h"

#include <algorithm>

#include "base/logging.h"

namespace webkit {
namespace ppapi {

base::LazyInstance<PpapiInterfaceFactoryManager>
    g_ppapi_interface_factory_manager(base::LINKER_INITIALIZED);

PpapiInterfaceFactoryManager::PpapiInterfaceFactoryManager() {
}

PpapiInterfaceFactoryManager::~PpapiInterfaceFactoryManager() {
}

void PpapiInterfaceFactoryManager::RegisterFactory(InterfaceFactory* factory) {
  DCHECK(std::find(interface_factory_list_.begin(),
                   interface_factory_list_.end(), factory) ==
         interface_factory_list_.end());
  interface_factory_list_.push_back(factory);
}

void PpapiInterfaceFactoryManager::UnregisterFactory(
    InterfaceFactory* factory) {
  FactoryList::iterator index =
      std::find(interface_factory_list_.begin(), interface_factory_list_.end(),
                factory);
  DCHECK(index != interface_factory_list_.end());
  interface_factory_list_.erase(index);
}

void* PpapiInterfaceFactoryManager::GetInterface(
    const std::string& interface_name) {
  FactoryList::iterator index;

  void* ppapi_interface = NULL;

  for (index = interface_factory_list_.begin();
       index != interface_factory_list_.end();
       ++index) {
    ppapi_interface = (*index)(interface_name);
    if (ppapi_interface)
      break;
  }
  return ppapi_interface;
}

// static
PpapiInterfaceFactoryManager* PpapiInterfaceFactoryManager::GetInstance() {
  return &g_ppapi_interface_factory_manager.Get();
}

}  // namespace ppapi
}  // namespace webkit

==> chromium-browser_15.0.874.106~r107270.orig.tar.bz2: chromium-15.0.874.106~r107270/src/webkit/plugins/ppapi/ppapi_interface_factory.cc <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "webkit/plugins/ppapi/ppapi_interface_factory.h"

#include <algorithm>

#include "base/logging.h"

namespace webkit {
namespace ppapi {

base::LazyInstance<PpapiInterfaceFactoryManager>
    g_ppapi_interface_factory_manager(base::LINKER_INITIALIZED);

PpapiInterfaceFactoryManager::PpapiInterfaceFactoryManager() {
}

PpapiInterfaceFactoryManager::~PpapiInterfaceFactoryManager() {
}

void PpapiInterfaceFactoryManager::RegisterFactory(InterfaceFactory* factory) {
  DCHECK(std::find(interface_factory_list_.begin(),
                   interface_factory_list_.end(), factory) ==
         interface_factory_list_.end());
  interface_factory_list_.push_back(factory);
}

void PpapiInterfaceFactoryManager::UnregisterFactory(
    InterfaceFactory* factory) {
  FactoryList::iterator index =
      std::find(interface_factory_list_.begin(), interface_factory_list_.end(),
                factory);
  if (index != interface_factory_list_.end())
    interface_factory_list_.erase(index);
}

const void* PpapiInterfaceFactoryManager::GetInterface(
    const std::string& interface_name) {
  FactoryList::iterator index;

  const void* ppapi_interface = NULL;

  for (index = interface_factory_list_.begin();
       index != interface_factory_list_.end();
       ++index) {
    ppapi_interface = (*index)(interface_name);
    if (ppapi_interface)
      break;
  }
  return ppapi_interface;
}

// static
PpapiInterfaceFactoryManager* PpapiInterfaceFactoryManager::GetInstance() {
  return &g_ppapi_interface_factory_manager.Get();
}

}  // namespace ppapi
}  // namespace webkit
